{% extends "imagestore/base.html" %}
{% load i18n %}
{% load thumbnail %}
{% load url from future %}
{% load imagestore_tags %}

{% block imagestore-breadcrumb %}
    {% with "li" as scope_tag %}
        {% include "imagestore/image-scope.html" %}
    {% endwith %}
{% endblock %}

{% block title %}
    {% include "imagestore/image-scope.html" %}
{% endblock %}

{% block imagestore-info %}
    {% if view_user and IMAGESTORE_SHOW_USER %}
        {% with user=view_user %}
            {% include "imagestore/user_info.html" %}
        {% endwith %}
    {% endif %}
    {% if album and IMAGESTORE_SHOW_USER %}
        {% with user=album.user %}
            {% include "imagestore/user_info.html" %}
        {% endwith %}
    {% endif %}

{% endblock %}


{% block controls %}
    {% if album %}
        {% if request.user == album.user or perms.imagestore.moderate_albums %}
            <li><a href='{% url 'imagestore:update-album' pk=album.pk %}'>{% trans "Edit album" %}</a></li>
        {% endif %}
    {% endif %}
{% endblock %}

{% block content %}
    <h1>
        {% include "imagestore/image-scope.html" %}
    </h1>
    {% include "imagestore/pagination.html" %}
    <div id="image-thumbnails">
        {% for image in image_list %}
            <div class='image-preview'>
            {% thumbnail image.image "120x120" crop="center" as im %}
                <a class="thumb" rel='gallery-image[ilist]' href="{{ image.image.url }}">
                    <img class="preview" {% imagestore_alt image forloop.counter %} src="{{ im.url }}">
                </a>
                <a href="{% include "imagestore/image-href.html" %}">
                    {% if image.title %}
                        <br><span class='image-title'>{{ image.title }}</span>
                    {% else %}
                        {% trans 'Info' %}
                    {% endif %}
                </a>
            {% endthumbnail %}
            </div>
        {% endfor %}
    </div>
    {% include "imagestore/pagination.html" %}
{% endblock %}


